@@ -12,7 +12,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Mapping, Sequence
 
 from .literals import (
     ArrayJobDependencyType,
@@ -224,7 +224,7 @@ _RequiredComputeResourceTypeDef = TypedDict(
     {
         "type": CRTypeType,
         "maxvCpus": int,
-        "subnets": List[str],
+        "subnets": Sequence[str],
     },
 )
 _OptionalComputeResourceTypeDef = TypedDict(
@@ -233,17 +233,17 @@ _OptionalComputeResourceTypeDef = TypedDict(
         "allocationStrategy": CRAllocationStrategyType,
         "minvCpus": int,
         "desiredvCpus": int,
-        "instanceTypes": List[str],
+        "instanceTypes": Sequence[str],
         "imageId": str,
-        "securityGroupIds": List[str],
+        "securityGroupIds": Sequence[str],
         "ec2KeyPair": str,
         "instanceRole": str,
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
         "placementGroup": str,
         "bidPercentage": int,
         "spotIamFleetRole": str,
         "launchTemplate": "LaunchTemplateSpecificationTypeDef",
-        "ec2Configuration": List["Ec2ConfigurationTypeDef"],
+        "ec2Configuration": Sequence["Ec2ConfigurationTypeDef"],
     },
     total=False,
 )
@@ -259,8 +259,8 @@ ComputeResourceUpdateTypeDef = TypedDict(
         "minvCpus": int,
         "maxvCpus": int,
         "desiredvCpus": int,
-        "subnets": List[str],
-        "securityGroupIds": List[str],
+        "subnets": Sequence[str],
+        "securityGroupIds": Sequence[str],
     },
     total=False,
 )
@@ -303,10 +303,10 @@ ContainerOverridesTypeDef = TypedDict(
     {
         "vcpus": int,
         "memory": int,
-        "command": List[str],
+        "command": Sequence[str],
         "instanceType": str,
-        "environment": List["KeyValuePairTypeDef"],
-        "resourceRequirements": List["ResourceRequirementTypeDef"],
+        "environment": Sequence["KeyValuePairTypeDef"],
+        "resourceRequirements": Sequence["ResourceRequirementTypeDef"],
     },
     total=False,
 )
@@ -360,7 +360,7 @@ _OptionalCreateComputeEnvironmentRequestRequestTypeDef = TypedDict(
         "state": CEStateType,
         "computeResources": "ComputeResourceTypeDef",
         "serviceRole": str,
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -387,14 +387,14 @@ _RequiredCreateJobQueueRequestRequestTypeDef = TypedDict(
     {
         "jobQueueName": str,
         "priority": int,
-        "computeEnvironmentOrder": List["ComputeEnvironmentOrderTypeDef"],
+        "computeEnvironmentOrder": Sequence["ComputeEnvironmentOrderTypeDef"],
     },
 )
 _OptionalCreateJobQueueRequestRequestTypeDef = TypedDict(
     "_OptionalCreateJobQueueRequestRequestTypeDef",
     {
         "state": JQStateType,
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -439,7 +439,7 @@ DeregisterJobDefinitionRequestRequestTypeDef = TypedDict(
 DescribeComputeEnvironmentsRequestRequestTypeDef = TypedDict(
     "DescribeComputeEnvironmentsRequestRequestTypeDef",
     {
-        "computeEnvironments": List[str],
+        "computeEnvironments": Sequence[str],
         "maxResults": int,
         "nextToken": str,
     },
@@ -458,7 +458,7 @@ DescribeComputeEnvironmentsResponseTypeDef = TypedDict(
 DescribeJobDefinitionsRequestRequestTypeDef = TypedDict(
     "DescribeJobDefinitionsRequestRequestTypeDef",
     {
-        "jobDefinitions": List[str],
+        "jobDefinitions": Sequence[str],
         "maxResults": int,
         "jobDefinitionName": str,
         "status": str,
@@ -479,7 +479,7 @@ DescribeJobDefinitionsResponseTypeDef = TypedDict(
 DescribeJobQueuesRequestRequestTypeDef = TypedDict(
     "DescribeJobQueuesRequestRequestTypeDef",
     {
-        "jobQueues": List[str],
+        "jobQueues": Sequence[str],
         "maxResults": int,
         "nextToken": str,
     },
@@ -498,7 +498,7 @@ DescribeJobQueuesResponseTypeDef = TypedDict(
 DescribeJobsRequestRequestTypeDef = TypedDict(
     "DescribeJobsRequestRequestTypeDef",
     {
-        "jobs": List[str],
+        "jobs": Sequence[str],
     },
 )
 
@@ -772,7 +772,7 @@ KeyValuesPairTypeDef = TypedDict(
     "KeyValuesPairTypeDef",
     {
         "name": str,
-        "values": List[str],
+        "values": Sequence[str],
     },
     total=False,
 )
@@ -809,7 +809,7 @@ ListJobsRequestRequestTypeDef = TypedDict(
         "jobStatus": JobStatusType,
         "maxResults": int,
         "nextToken": str,
-        "filters": List["KeyValuesPairTypeDef"],
+        "filters": Sequence["KeyValuesPairTypeDef"],
     },
     total=False,
 )
@@ -899,7 +899,7 @@ NodeOverridesTypeDef = TypedDict(
     "NodeOverridesTypeDef",
     {
         "numNodes": int,
-        "nodePropertyOverrides": List["NodePropertyOverrideTypeDef"],
+        "nodePropertyOverrides": Sequence["NodePropertyOverrideTypeDef"],
     },
     total=False,
 )
@@ -985,14 +985,14 @@ _RequiredRegisterJobDefinitionRequestRequestTypeDef = TypedDict(
 _OptionalRegisterJobDefinitionRequestRequestTypeDef = TypedDict(
     "_OptionalRegisterJobDefinitionRequestRequestTypeDef",
     {
-        "parameters": Dict[str, str],
+        "parameters": Mapping[str, str],
         "containerProperties": "ContainerPropertiesTypeDef",
         "nodeProperties": "NodePropertiesTypeDef",
         "retryStrategy": "RetryStrategyTypeDef",
         "propagateTags": bool,
         "timeout": "JobTimeoutTypeDef",
-        "tags": Dict[str, str],
-        "platformCapabilities": List[PlatformCapabilityType],
+        "tags": Mapping[str, str],
+        "platformCapabilities": Sequence[PlatformCapabilityType],
     },
     total=False,
 )
@@ -1063,14 +1063,14 @@ _OptionalSubmitJobRequestRequestTypeDef = TypedDict(
     "_OptionalSubmitJobRequestRequestTypeDef",
     {
         "arrayProperties": "ArrayPropertiesTypeDef",
-        "dependsOn": List["JobDependencyTypeDef"],
-        "parameters": Dict[str, str],
+        "dependsOn": Sequence["JobDependencyTypeDef"],
+        "parameters": Mapping[str, str],
         "containerOverrides": "ContainerOverridesTypeDef",
         "nodeOverrides": "NodeOverridesTypeDef",
         "retryStrategy": "RetryStrategyTypeDef",
         "propagateTags": bool,
         "timeout": "JobTimeoutTypeDef",
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -1096,7 +1096,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
 )
 
@@ -1141,7 +1141,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "tagKeys": List[str],
+        "tagKeys": Sequence[str],
     },
 )
 
@@ -1189,7 +1189,7 @@ _OptionalUpdateJobQueueRequestRequestTypeDef = TypedDict(
     {
         "state": JQStateType,
         "priority": int,
-        "computeEnvironmentOrder": List["ComputeEnvironmentOrderTypeDef"],
+        "computeEnvironmentOrder": Sequence["ComputeEnvironmentOrderTypeDef"],
     },
     total=False,
 )
